# he-no-interference

The code was written to compute the semiclassical magnetoresistance response in order to explain the Bloch-Lorentz oscillations observed in quasi-two-dimensional materials by [Putzke et al.](https://science.sciencemag.org/content/368/6496/1234) The code is divided into three parts:

- **`numerical_analysis`**. Contains Jupyter notebooks `inplane_magnetoresistance.ipynb` and `outofplane_magnetoresistance.ipynb` used to generate magnetoresistance data for in-plane and out-of-plane magnetic fields. Additionally, `2D_boundary_calc.ipynb` calculates the magnetoresistance for  a realistic sample geometry, but neglects scattering relaxation. The `modules/quasi2d.py` contains its numerical implementation.
- **`figures`**. Houses the code for generating figures seen in the paper.
- **`data`**. Contains the numerical data from `numerical_analysis` and the experimental data from [Putzke et al.](https://zenodo.org/record/3725930)

## Installation
Make sure you have [anaconda](https://docs.conda.io/projects/conda/en/latest/user-guide/install/) installed. To install the python environment, run:

```
conda env create -f environment.yml
```

then activate it with
```
source activate he-oscillations
```

## Running the code 
To run the magnetoresistance calculations in `numerical_analysis`, run the command:
```
jupyter lab
```
If wish to run `outofplane_magnetoresistance.ipynb` locally, make sure run the following command before opening up jupyter lab:
```
ipcluster start -n 4
```
where 4 is the choice of cores.

To generate the figure x seen in the paper, run:
```
python figurex.py
```
