from matplotlib import pyplot as plt
from matplotlib.lines import Line2D
import matplotlib as mpl
tex_settings = {                      
     "text.usetex": True,
     "font.family": "sans-serif",
     "font.serif" : "Computer Modern Roman",
     "text.latex.preamble": [
         r"\usepackage{siunitx}",
         r" \usepackage[version=4]{mhchem}",
         r"\sisetup{detect-all}"
         ]
     }
mpl.rcParams.update(tex_settings)
import numpy as np
import xarray as xr
from pathlib import Path

MAIN_FOLDER = Path('../../data/theory/2D_boundary')
data = xr.load_dataset(MAIN_FOLDER/Path('2021-03-16-19-43-00'))
data = data['__xarray_dataarray_variable__']

column_size = 5.90666
fig, ax = plt.subplots(1,1,figsize=(column_size,column_size/1.61803398875))

cmap = plt.cm.viridis(np.linspace(0, 1, np.size(data[0,0,:,0])))
for count, i in enumerate(data[0,0,:,0]):
    rho = 1/data[:,0,count,0]
    rho = rho/rho[0]
    ax.plot(data['By'],rho-1, c=cmap[count])

ax.set_ylabel('$ \\Delta \\rho(B)/\\rho(0) $', fontsize = 14)
ax.set_xlabel(r'$B[T]$', fontsize = 14)
ax.set_ylim([0, 50])
ax.set_xlim([0, 10])

lines = [Line2D([0], [0], c=c ) for c in cmap]
labels = [ 3.9,   4.5,   5,   6,   8,  10,  20,  40, 100]
leg = ax.legend(lines, labels, title=r"\ce{PdCoO2} $W=$\SI{5.5}{\micro\meter} and $L$ (\si{\micro\meter}):", frameon=False)
leg._legend_box.align = "left"
fig.savefig("../figure3.svg", bbox_inches='tight', transparent=False, dpi=1000)
