from math import sqrt,pi
from autograd import grad
import autograd.numpy as np

# Defining the primitive cell and tight-binding hopping terms for the system (angstroms and eV)
C = 17.743/3
A = 2.830
TNN = 1
TNNN = 0.14
TZZ = 0.01
TZZZ = 0.011

# Defining the crystallographic vectors for the unit cell
_AV = np.array([1, 0, 0])*A
_BV = np.array([np.cos(2/3*pi), np.cos(1/6*pi), 0])*A
_CV = np.array([0, 0, 1])*C

def Pd_energy(kx,ky,kz):
    """ PdCoO2 energy dispersion
    
    Arguments:
        kx {float} -- wave vector, in Angstroms
        ky {float} -- wave vector, in Angstroms
        kz {float} -- wave vector, in Angstroms
    
    Returns:
        float -- energy (eV)
    """
    k = np.moveaxis(np.array([kx, ky, kz]), 0, -1)

    energy_nn = -2*TNN*(np.cos(np.dot(k,_AV))+np.cos(np.dot(k,_BV))+np.cos(np.dot(k,_AV+_BV)))-2*TZZ*np.cos(np.dot(k,_CV))
    energy_nnn = -2*TNNN*(np.cos(np.dot(k,_AV))**2+np.cos(np.dot(k,_BV))**2+np.cos(np.dot(k,_AV+_BV))**2)
    energy_t = energy_nn + energy_nnn
    return energy_t